==> dnet-oai-store-service-4.4.1-20150720.093128-1-sources.jar: eu/dnetlib/data/oai/store/mongo/RecordInfoGenerator.java <==
package eu.dnetlib.data.oai.store.mongo;

import java.io.StringReader;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang.StringEscapeUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.io.SAXReader;

import com.google.common.collect.Sets;
import com.mongodb.DBObject;

import eu.dnetlib.data.information.oai.publisher.OaiPublisherRuntimeException;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationReader;
import eu.dnetlib.data.information.oai.publisher.info.RecordInfo;

/**
 * Helper class to generate a RecordInfo object from a Mongo DBObject.
 * 
 * @author alessia
 * 
 */
public class RecordInfoGenerator {

	@Resource
	private MetadataExtractor metadataExtractor;
	@Resource
	private ProvenanceExtractor provenanceExtractor;

	@SuppressWarnings("unchecked")
	public RecordInfo transformDBObject(final DBObject object, final boolean includeBody) {
		if ((object == null) || object.keySet().isEmpty()) return null;
		String id = (String) object.get(OAIConfigurationReader.ID_FIELD);
		// need to escape the identifier, otherwise the XML breaks
		id = StringEscapeUtils.escapeXml(id);
		boolean deleted = (Boolean) object.get("deleted");
		RecordInfo record = new RecordInfo();
		record.setIdentifier(id);
		record.setInternalId(object.get("_id").toString());
		record.setDatestamp((Date) object.get(OAIConfigurationReader.DATESTAMP_FIELD));
		record.setDeleted(deleted);
		List<String> sets = (List<String>) object.get(OAIConfigurationReader.SET_FIELD);
		if (sets != null) {
			record.setSetspecs(Sets.newHashSet(sets));
		}
		if (includeBody && !deleted) {
			String body = (String) object.get(OAIConfigurationReader.BODY_FIELD);
			final SAXReader reader = new SAXReader();
			Document doc;
			try {
				doc = reader.read(new StringReader(body));
				record.setMetadata(this.metadataExtractor.evaluate(doc));
				record.setProvenance(this.provenanceExtractor.evaluate(doc));
			} catch (DocumentException e) {
				throw new OaiPublisherRuntimeException(e);
			}
		}
		return record;

	}

	public MetadataExtractor getMetadataExtractor() {
		return metadataExtractor;
	}

	public void setMetadataExtractor(final MetadataExtractor metadataExtractor) {
		this.metadataExtractor = metadataExtractor;
	}

	public ProvenanceExtractor getProvenanceExtractor() {
		return provenanceExtractor;
	}

	public void setProvenanceExtractor(final ProvenanceExtractor provenanceExtractor) {
		this.provenanceExtractor = provenanceExtractor;
	}
}

==> dnet-oai-store-service-6.1.2-20170316.181315-21-sources.jar: eu/dnetlib/data/oai/store/mongo/RecordInfoGenerator.java <==
package eu.dnetlib.data.oai.store.mongo;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.StringReader;
import java.util.Date;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

import javax.annotation.Resource;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringEscapeUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.io.SAXReader;

import com.google.common.collect.Sets;
import com.mongodb.DBObject;

import eu.dnetlib.data.information.oai.publisher.OaiPublisherRuntimeException;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationReader;
import eu.dnetlib.data.information.oai.publisher.info.RecordInfo;

/**
 * Helper class to generate a RecordInfo object from a Mongo DBObject.
 *
 * @author alessia
 *
 */
public class RecordInfoGenerator {

	@Resource
	private MetadataExtractor metadataExtractor;
	@Resource
	private ProvenanceExtractor provenanceExtractor;

	@SuppressWarnings("unchecked")
	public RecordInfo transformDBObject(final DBObject object, final boolean includeBody) {
		if ((object == null) || object.keySet().isEmpty()) return null;
		String id = (String) object.get(OAIConfigurationReader.ID_FIELD);
		// need to escape the identifier, otherwise the XML breaks
		id = StringEscapeUtils.escapeXml(id);
		boolean deleted = (Boolean) object.get("deleted");
		RecordInfo record = new RecordInfo();
		record.setIdentifier(id);
		record.setInternalId(object.get("_id").toString());
		record.setDatestamp((Date) object.get(OAIConfigurationReader.DATESTAMP_FIELD));
		record.setDeleted(deleted);
		List<String> sets = (List<String>) object.get(OAIConfigurationReader.SET_FIELD);
		if (sets != null) {
			record.setSetspecs(Sets.newHashSet(sets));
		}
		if (includeBody && !deleted) {
			String body = decompressRecord((byte[]) object.get(OAIConfigurationReader.BODY_FIELD));
			final SAXReader reader = new SAXReader();
			Document doc;
			try {
				doc = reader.read(new StringReader(body));
				record.setMetadata(this.metadataExtractor.evaluate(doc));
				record.setProvenance(this.provenanceExtractor.evaluate(doc));
			} catch (DocumentException e) {
				throw new OaiPublisherRuntimeException(e);
			}
		}
		return record;

	}

	public  String decompressRecord(final byte[] input)  {

		try {
			ByteArrayInputStream bis = new ByteArrayInputStream(input);
			ZipInputStream zis = new ZipInputStream(bis);
			ZipEntry ze;
			ze = zis.getNextEntry();
			if (ze== null)
				throw new OaiPublisherRuntimeException("cannot decompress null zip entry ");
			if (!ze.getName().equals(OAIConfigurationReader.BODY_FIELD))
				throw new OaiPublisherRuntimeException("cannot decompress zip entry name :"+ze.getName());
			return IOUtils.toString(zis);
		} catch (IOException e) {
			throw new OaiPublisherRuntimeException(e);
		}


	}

	public MetadataExtractor getMetadataExtractor() {
		return metadataExtractor;
	}

	public void setMetadataExtractor(final MetadataExtractor metadataExtractor) {
		this.metadataExtractor = metadataExtractor;
	}

	public ProvenanceExtractor getProvenanceExtractor() {
		return provenanceExtractor;
	}

	public void setProvenanceExtractor(final ProvenanceExtractor provenanceExtractor) {
		this.provenanceExtractor = provenanceExtractor;
	}
}
